<?php
 namespace App\Controller\Frontend; use Symfony\Component\HttpFoundation\Request; use Symfony\Component\HttpFoundation\Response; use Symfony\Component\Form\Form; use Symfony\Component\Form\Extension\Core\Type\SubmitType; use Symfony\Contracts\Translation\TranslatorInterface; use Symfony\Component\Validator\Validator\ValidatorInterface; use Symfony\Component\Validator\ConstraintViolationList; use App\Controller\Controller; use App\Event\EventQueue; use App\Service\Logger; use App\Entity\Site as SiteEntity; use App\Entity\Certificate as CertificateEntity; use App\Entity\NodejsSettings as NodejsSettingsEntity; use App\Entity\PhpSettings as PhpSettingsEntity; use App\Entity\PythonSettings as PythonSettingsEntity; use App\Entity\Database as DatabaseEntity; use App\Entity\DatabaseUser as DatabaseUserEntity; use App\Entity\DatabaseServer as DatabaseServerEntity; use App\Entity\User as UserEntity; use App\Entity\Manager\ConfigManager; use App\Entity\Manager\SiteManager as SiteEntityManager; use App\Entity\Manager\CertificateManager as CertificateEntityManager; use App\Entity\Manager\DatabaseManager as DatabaseEntityManager; use App\Entity\Manager\DatabaseUserManager as DatabaseUserEntityManager; use App\Entity\Manager\DatabaseServerManager as DatabaseServerEntityManager; use App\Entity\Manager\VhostTemplateManager as VhostTemplateEntityManager; use App\Database\Connection as DatabaseConnection; use App\Database\Manager as DatabaseManager; use App\Site\Nginx\Vhost\StaticTemplate as StaticVhostTemplate; use App\Site\Nginx\Vhost\PhpTemplate as PhpVhostTemplate; use App\Site\Nginx\Vhost\PythonTemplate as PythonVhostTemplate; use App\Site\Nginx\Vhost\ReverseProxyTemplate as ReverseProxyVhostTemplate; use App\Site\Nginx\Vhost\Processor\RedirectDomain as RedirectDomainProcessor; use App\Site\Nginx\Vhost\Processor\RedirectServerName as RedirectServerNameProcessor; use App\Site\Nginx\Vhost\Processor\ServerName as ServerNameProcessor; use App\Site\Parser\DomainName as DomainNameParser; use App\Site\Ssl\Generator\RsaKeyGenerator; use App\Site\Creator\NodejsSite as NodejsSiteCreator; use App\Site\Creator\StaticSite as StaticSiteCreator; use App\Site\Creator\PhpSite as PhpSiteCreator; use App\Site\Creator\PythonSite as PythonSiteCreator; use App\Site\Creator\ReverseProxySite as ReverseProxySiteCreator; use App\Site\Ssl\DistinguishedName; use App\Site\Ssl\Generator\CsrGenerator; use App\Site\Ssl\Util\Openssl; use App\Site\NodejsSite; use App\Site\StaticSite; use App\Site\PhpSite; use App\Site\PythonSite; use App\Site\ReverseProxySite; use App\Util\PasswordGenerator; use App\Site\Application\WordPressInstaller; use App\Service\Crypto; class NewSiteController extends Controller { private const WORDPRESS_VHOST_TEMPLATE_NAME = "\x57\157\162\x64\120\x72\145\x73\x73"; private const NODEJS_VHOST_TEMPLATE_NAME = "\116\x6f\144\145\x6a\x73"; private const STATIC_SITE_VHOST_TEMPLATE_NAME = "\123\164\x61\164\151\x63"; private const PYTHON_VHOST_TEMPLATE_NAME = "\120\171\x74\x68\x6f\x6e"; private const REVERSE_PROXY_VHOST_TEMPLATE_NAME = "\122\x65\166\x65\162\163\x65\120\x72\x6f\x78\171"; private const VARNISH_CACHE_SERVER = "\61\x32\x37\x2e\60\x2e\x30\56\x31\x3a\66\x30\x38\x31"; private const PASSWORD_LENGTH = 20; private ConfigManager $configManager; private SiteEntityManager $siteEntityManager; private CertificateEntityManager $certificateEntityManager; private DatabaseEntityManager $databaseEntityManager; private DatabaseUserEntityManager $databaseUserEntityManager; private DatabaseServerEntityManager $databaseServerEntityManager; private DomainNameParser $domainNameParser; private VhostTemplateEntityManager $vhostTemplateEntityManager; private ValidatorInterface $validator; private array $wordPressDefaultConfigValues = ["\x46\123\137\115\105\124\110\117\x44" => ["\166\x61\154\165\x65" => "\x64\151\x72\145\x63\164", "\x72\x61\x77" => false], "\x57\120\x5f\x44\105\x42\x55\107\x5f\104\111\x53\120\114\101\x59" => ["\166\x61\x6c\165\x65" => "\146\141\x6c\x73\x65", "\162\x61\x77" => true], "\x57\120\x5f\x44\105\x42\125\x47\137\114\117\x47" => ["\x76\x61\x6c\x75\145" => "\x74\x72\x75\x65", "\162\x61\x77" => true], "\103\117\116\103\x41\124\x45\116\101\124\x45\137\123\x43\x52\x49\120\x54\123" => ["\166\x61\154\x75\145" => "\x66\141\154\163\x65", "\162\141\x77" => true], "\101\x55\x54\x4f\123\x41\126\x45\x5f\111\116\124\105\x52\126\x41\x4c" => ["\166\x61\x6c\165\145" => 600, "\x72\x61\x77" => true], "\x57\x50\x5f\120\117\123\124\x5f\122\105\126\x49\123\x49\117\x4e\x53" => ["\166\x61\x6c\165\x65" => 5, "\x72\141\167" => true], "\105\115\x50\x54\131\137\124\122\x41\123\110\x5f\104\x41\131\x53" => ["\x76\x61\x6c\x75\145" => 21, "\x72\x61\x77" => true]]; private array $wordPressMultiSiteConfigValues = ["\127\x50\x5f\x41\x4c\x4c\117\x57\x5f\115\125\114\124\111\123\x49\124\105" => ["\x76\x61\x6c\x75\x65" => "\x74\162\x75\145", "\x72\x61\167" => true], "\115\125\114\x54\x49\x53\111\124\105" => ["\166\141\x6c\x75\x65" => "\164\162\x75\x65", "\x72\141\x77" => true], "\x53\x55\x42\104\x4f\115\101\111\116\x5f\x49\116\123\x54\101\114\x4c" => ["\166\141\x6c\165\145" => "\x66\x61\154\163\145", "\x72\141\x77" => true], "\x44\x4f\x4d\101\x49\116\137\x43\125\122\122\105\116\124\x5f\123\x49\x54\x45" => ["\x76\x61\x6c\x75\145" => '', "\162\x61\167" => false], "\120\x41\x54\x48\x5f\x43\x55\x52\122\x45\116\x54\137\123\x49\x54\105" => ["\166\x61\154\x75\145" => "\x2f", "\x72\x61\167" => false], "\x53\x49\x54\105\137\x49\104\x5f\103\125\x52\x52\x45\x4e\x54\137\123\x49\x54\105" => ["\166\x61\154\165\x65" => 1, "\162\141\x77" => true], "\102\114\117\107\x5f\111\x44\x5f\x43\x55\x52\122\105\x4e\x54\137\123\111\x54\105" => ["\166\x61\154\165\145" => 1, "\162\x61\x77" => true]]; public function __construct(ConfigManager $configManager, SiteEntityManager $siteEntityManager, CertificateEntityManager $certificateEntityManager, DatabaseEntityManager $databaseEntityManager, DatabaseUserEntityManager $databaseUserEntityManager, DatabaseServerEntityManager $databaseServerEntityManager, VhostTemplateEntityManager $vhostTemplateEntityManager, DomainNameParser $domainNameParser, ValidatorInterface $validator, TranslatorInterface $translator, Logger $logger) { goto a3ae3; C6f13: $this->vhostTemplateEntityManager = $vhostTemplateEntityManager; goto F08ff; D0bd3: $this->validator = $validator; goto D06a3; A4d60: $this->certificateEntityManager = $certificateEntityManager; goto d69af; d69af: $this->databaseEntityManager = $databaseEntityManager; goto B0c66; B0c66: $this->databaseUserEntityManager = $databaseUserEntityManager; goto Dfecb; a3ae3: $this->configManager = $configManager; goto B11e8; B11e8: $this->siteEntityManager = $siteEntityManager; goto A4d60; F08ff: $this->domainNameParser = $domainNameParser; goto D0bd3; Dfecb: $this->databaseServerEntityManager = $databaseServerEntityManager; goto C6f13; D06a3: parent::__construct($translator, $logger); goto Bd342; Bd342: } public function index(Request $request) : Response { goto ed36a; B3442: $response = $this->redirect($this->generateUrl("\x63\x6c\160\x5f\163\x69\164\145\x73")); goto b3e10; A3c95: if (true === $hasPermissions) { goto C2f88; } goto B3442; ed36a: $hasPermissions = $this->hasPermissions(); goto A3c95; ed166: return $response; goto F6052; af1c2: C2f88: goto Ccad7; A00ee: Da30a: goto ed166; adcb6: $response = $this->render("\106\162\x6f\x6e\x74\x65\156\144\57\123\x69\164\145\x2f\116\x65\167\57\151\x6e\144\145\x78\x2e\150\164\155\154\56\x74\x77\x69\147", ["\x75\x73\145\x72" => $user]); goto A00ee; b3e10: goto Da30a; goto af1c2; Ccad7: $user = $this->getUser(); goto adcb6; F6052: } public function newPythonSite(Request $request) : Response { goto f99ce; B1309: ffa84: goto E07f0; C83a0: f8b9d: goto c3d27; D00aa: return $response; goto B1309; ef2ab: return $response; goto bf50d; D1380: $form = $this->createPythonSiteForm($pythonSettings); goto A3a6a; f99ce: $hasPermissions = $this->hasPermissions(); goto Fc243; E07f0: be6ef: goto b46d4; Eca09: if (!(true === $form->isSubmitted())) { goto be6ef; } goto ad585; Ae8b2: $form->handleRequest($request); goto Eca09; Bea3c: $pythonSettings = new PythonSettingsEntity(); goto D1380; b46d4: Ec847: goto D5681; f4eba: goto a9d60; goto C83a0; b1263: a9d60: goto ef2ab; ad585: $response = $this->handleCreatePythonSiteForm($request, $form); goto e1c46; ade0f: $response = $this->redirect($this->generateUrl("\x63\154\160\137\163\151\x74\x65\163")); goto f4eba; D5681: $response = $this->render("\x46\x72\157\x6e\164\145\156\x64\x2f\123\151\x74\145\57\x4e\145\167\x2f\160\x79\164\x68\x6f\x6e\56\150\164\155\154\56\164\167\x69\x67", ["\x75\163\145\x72" => $user, "\146\157\162\155" => $form->createView(), "\x66\x6f\162\155\105\162\162\157\162\x73" => $this->formErrors]); goto b1263; A3a6a: if (!(true === $request->isMethod("\x50\x4f\123\124"))) { goto Ec847; } goto Ae8b2; e1c46: if (!(false === is_null($response))) { goto ffa84; } goto D00aa; Fc243: if (true === $hasPermissions) { goto f8b9d; } goto ade0f; c3d27: $user = $this->getUser(); goto Bea3c; bf50d: } private function createPythonSiteForm(PythonSettingsEntity $pythonSettings) : Form { goto C269d; B573b: $form->add("\x73\x75\142\x6d\151\164", SubmitType::class, ["\x61\164\164\162" => ["\x63\154\x61\163\163" => "\x62\x74\156\40\142\164\156\x2d\154\x67\40\142\x74\156\x2d\142\x6c\x75\145"], "\x6c\141\142\145\x6c" => "\x43\x72\x65\x61\x74\145"]); goto Ae24b; Ae24b: return $form; goto Ef4fd; C269d: $form = $this->createForm("\x41\x70\160\x5c\x46\157\x72\x6d\134\123\151\x74\145\x4e\145\x77\x50\x79\x74\x68\x6f\x6e\124\171\160\x65", $pythonSettings, ["\x61\143\x74\x69\x6f\x6e" => $this->generateUrl("\143\154\160\x5f\x73\151\x74\145\x5f\x70\171\164\150\157\156\137\156\145\167"), "\x6d\x65\x74\x68\x6f\x64" => "\x50\117\123\124", "\141\x74\x74\162" => ["\151\144" => "\x6e\145\x77\x2d\x70\x79\164\150\x6f\x6e\55\163\x69\x74\145\x2d\x66\157\x72\x6d"]]); goto B573b; Ef4fd: } private function handleCreatePythonSiteForm(Request $request, Form $form) { goto e9338; e9338: if (true === $form->isValid()) { goto ae6eb; } goto e8727; Ea2f0: try { goto fc882; fe8b8: $siteUserPassword = $form->get("\x73\151\x74\x65\x55\163\x65\x72\120\x61\163\x73\x77\x6f\162\x64")->getData(); goto fa79f; A2652: EventQueue::addEvent(EventQueue::EVENT_SITE_PYTHON_CREATE, $user, $eventData, $request); goto Af3cd; fa79f: $vhostTemplateName = self::PYTHON_VHOST_TEMPLATE_NAME; goto cfb4c; f78bc: throw new \Exception(sprintf("\126\150\x6f\163\x74\x20\164\x65\x6d\x70\x6c\141\164\x65\40\42\45\163\x22\40\156\x6f\x74\x20\146\x6f\165\156\144\x2e", $vhostTemplateName)); goto Cc10b; e9c5d: abcac: goto f3bde; e5a10: $eventData = ["\x73\151\x74\145" => $domainName, "\x73\x69\x74\145\x55\163\145\162" => $siteUser, "\x70\171\x74\150\x6f\x6e\126\x65\162\163\x69\x6f\156" => $pythonVersion, "\x70\x6f\162\164" => $port]; goto A2652; be49a: $domainName = $form->get("\x64\157\x6d\x61\151\x6e\116\x61\x6d\x65")->getData(); goto Bb8f0; fc882: $session = $request->getSession(); goto be49a; Ff6e3: if (false === is_null($vhostTemplateEntity)) { goto abcac; } goto f78bc; C1d64: F31e5: goto bb2a6; Af3cd: $session->getFlashBag()->set("\163\165\143\143\145\x73\x73", $this->translator->trans("\x53\x69\x74\145\x20\150\141\x73\x20\142\145\x65\156\x20\x63\162\x65\x61\164\x65\x64\x2e")); goto A581f; cfb4c: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Ff6e3; Bb8f0: $pythonVersion = $form->get("\x70\171\x74\x68\x6f\156\x56\x65\162\x73\x69\x6f\x6e")->getData(); goto cea0c; Cc10b: goto F31e5; goto e9c5d; D62ca: $this->createPythonSite($domainName, $pythonVersion, $port, $siteUser, $siteUserPassword); goto e5a10; cea0c: $port = $form->get("\x70\x6f\x72\x74")->getData(); goto d8ca8; f68e8: return $response; goto C1d64; A581f: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\x5f\163\151\164\145\x73")); goto f68e8; f3bde: $user = $this->getUser(); goto D62ca; d8ca8: $siteUser = $form->get("\x73\151\x74\145\125\163\x65\x72")->getData(); goto fe8b8; bb2a6: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\156\147\x65\x72", $this->translator->trans("\101\156\40\145\162\x72\157\162\40\150\x61\163\40\157\143\143\165\162\162\145\x64\54\x20\145\x72\162\157\162\x20\x6d\x65\x73\163\141\147\145\x3a\x20\x25\145\162\162\x6f\x72\115\x65\x73\163\x61\147\x65\x25", ["\x25\145\x72\162\x6f\162\x4d\145\x73\163\141\x67\x65\x25" => $e->getMessage()])); } goto F57b0; e8727: $this->formErrors = $this->getErrorMessages($form); goto D5bb9; D5bb9: goto C71a9; goto D5b29; D5b29: ae6eb: goto Ea2f0; F57b0: C71a9: goto C1a1c; C1a1c: } public function newReverseProxy(Request $request) : Response { goto c7f0f; b23d7: if (!(true === $request->isMethod("\120\117\123\124"))) { goto bcb6a; } goto d18d7; d5cff: a107b: goto ed9a9; a34ec: if (true === $hasPermissions) { goto a01f4; } goto c63e7; F5829: a01f4: goto Ca3fd; d453c: if (!(true === $form->isSubmitted())) { goto B2c06; } goto Bdb00; dfbda: B2c06: goto F9d51; F9d51: bcb6a: goto fba29; Ca3fd: $user = $this->getUser(); goto ed41b; F3e7f: if (!(false === is_null($response))) { goto f116a; } goto a2d4b; Fdc80: goto a107b; goto F5829; fba29: $response = $this->render("\106\x72\x6f\156\164\x65\x6e\x64\x2f\123\151\164\145\x2f\x4e\145\x77\57\162\145\x76\145\162\163\145\55\x70\x72\157\170\171\56\x68\x74\155\x6c\56\164\x77\151\x67", ["\x75\x73\x65\x72" => $user, "\x66\157\162\x6d" => $form->createView(), "\146\x6f\x72\155\x45\x72\x72\x6f\x72\x73" => $this->formErrors]); goto d5cff; d18d7: $form->handleRequest($request); goto d453c; a2d4b: return $response; goto af5c1; Bdb00: $response = $this->handleReverseProxyForm($request, $form); goto F3e7f; af5c1: f116a: goto dfbda; ed41b: $form = $this->createReverseProxyForm(); goto b23d7; ed9a9: return $response; goto f34ac; c7f0f: $hasPermissions = $this->hasPermissions(); goto a34ec; c63e7: $response = $this->redirect($this->generateUrl("\143\154\160\x5f\x73\x69\x74\145\x73")); goto Fdc80; f34ac: } private function createReverseProxyForm() : Form { goto F230d; f7545: return $form; goto cee19; bf98b: $form->add("\163\165\x62\155\x69\x74", SubmitType::class, ["\141\164\x74\x72" => ["\x63\154\x61\163\x73" => "\142\x74\156\x20\x62\x74\x6e\55\x6c\x67\x20\x62\164\156\x2d\x62\154\165\145"], "\x6c\141\142\x65\154" => "\103\162\145\141\164\145"]); goto f7545; F230d: $form = $this->createForm("\101\160\160\134\x46\x6f\162\155\134\x53\151\164\x65\116\x65\167\122\x65\166\x65\162\163\145\x50\x72\x6f\170\x79\x54\171\x70\145", [], ["\141\x63\x74\151\x6f\156" => $this->generateUrl("\x63\154\x70\137\x73\x69\164\x65\137\x72\x65\x76\x65\162\x73\x65\x5f\160\x72\157\x78\x79\x5f\156\145\167"), "\x6d\145\164\150\157\x64" => "\x50\117\123\x54", "\x61\x74\x74\162" => ["\151\144" => "\x6e\x65\x77\x2d\162\145\x76\145\162\x73\x65\55\x70\x72\x6f\170\x79\x2d\146\157\162\x6d"]]); goto bf98b; cee19: } private function handleReverseProxyForm(Request $request, Form $form) { goto Bbb66; f3fb3: B0cc0: goto cbc49; C930f: goto D5d67; goto f3fb3; C0a55: $this->formErrors = $this->getErrorMessages($form); goto C930f; Bbb66: if (true === $form->isValid()) { goto B0cc0; } goto C0a55; e9b75: D5d67: goto c6fa4; cbc49: try { goto ac116; f3a86: $user = $this->getUser(); goto d283f; d4d3e: throw new \Exception(sprintf("\126\x68\x6f\163\164\x20\164\145\155\x70\x6c\141\164\x65\40\42\45\x73\42\x20\156\157\164\x20\x66\x6f\x75\x6e\144\56", $vhostTemplateName)); goto E8aa3; Dea03: A2dba: goto f3a86; d283f: $this->createReverseProxySite($domainName, $reverseProxyUrl, $siteUser, $siteUserPassword); goto A3fd3; ac116: $session = $request->getSession(); goto c1972; A2a14: Acda8: goto E2635; F9232: $siteUserPassword = $form->get("\163\x69\x74\x65\125\x73\x65\x72\120\141\x73\163\167\x6f\x72\144")->getData(); goto F7daa; E169b: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Bb921; F7daa: $reverseProxyUrl = $form->get("\162\x65\x76\x65\162\x73\145\x50\x72\x6f\x78\x79\x55\162\154")->getData(); goto bc30d; A3fd3: $eventData = ["\163\151\x74\x65" => $domainName, "\163\151\164\145\125\163\x65\x72" => $siteUser, "\162\x65\x76\x65\162\163\145\x50\162\x6f\170\x79\x55\x72\154" => $reverseProxyUrl]; goto B4d80; Cb421: $session->getFlashBag()->set("\163\165\x63\x63\x65\163\x73", $this->translator->trans("\x52\145\x76\145\162\163\x65\40\x50\162\157\170\171\40\x68\141\163\x20\x62\145\145\156\x20\143\162\145\141\x74\x65\x64\56")); goto E075d; E8aa3: goto Acda8; goto Dea03; e1e74: $siteUser = $form->get("\163\x69\164\145\x55\x73\145\162")->getData(); goto F9232; B4d80: EventQueue::addEvent(EventQueue::EVENT_SITE_REVERSE_PROXY_CREATE, $user, $eventData, $request); goto Cb421; bc30d: $vhostTemplateName = self::REVERSE_PROXY_VHOST_TEMPLATE_NAME; goto E169b; E075d: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\x5f\x73\151\x74\x65\163")); goto a88dc; a88dc: return $response; goto A2a14; Bb921: if (false === is_null($vhostTemplateEntity)) { goto A2dba; } goto d4d3e; c1972: $domainName = $form->get("\x64\157\155\141\151\156\116\x61\x6d\x65")->getData(); goto e1e74; E2635: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\x6e\147\145\x72", $this->translator->trans("\101\156\x20\x65\162\x72\x6f\162\40\x68\x61\x73\40\157\143\x63\165\x72\x72\145\144\54\40\145\x72\162\157\162\x20\x6d\x65\x73\x73\x61\147\x65\x3a\x20\x25\x65\162\162\x6f\162\x4d\145\163\163\141\147\145\45", ["\x25\145\162\162\x6f\162\115\x65\x73\x73\x61\x67\145\x25" => $e->getMessage()])); } goto e9b75; c6fa4: } public function newNodejsSite(Request $request) : Response { goto c3170; Cecd5: f5bf9: goto Bbc2f; Bbc2f: $response = $this->render("\106\162\157\x6e\164\145\156\144\x2f\123\151\164\x65\x2f\116\145\167\x2f\156\x6f\144\x65\152\163\x2e\150\x74\155\154\56\x74\x77\x69\x67", ["\165\x73\145\162" => $user, "\x66\x6f\162\155" => $form->createView(), "\146\x6f\162\155\105\162\x72\x6f\162\163" => $this->formErrors]); goto f9317; c3170: $hasPermissions = $this->hasPermissions(); goto Fdd52; e8530: if (!(true === $form->isSubmitted())) { goto b83e4; } goto Fe51c; e76c8: $form = $this->createNodejsSiteForm($nodejsSettings); goto d45c3; ada65: goto Cb9bc; goto Ad1ec; f9317: Cb9bc: goto c7ac8; Db2ec: return $response; goto E533a; Ad3e4: $form->handleRequest($request); goto e8530; A6c8a: $response = $this->redirect($this->generateUrl("\143\x6c\x70\x5f\163\x69\x74\145\163")); goto ada65; Fe51c: $response = $this->handleCreateNodejsSiteForm($request, $form); goto e551e; dc500: b83e4: goto Cecd5; F87d6: $user = $this->getUser(); goto C10cb; c7ac8: return $response; goto C79e3; e551e: if (!(false === is_null($response))) { goto A4564; } goto Db2ec; Fdd52: if (true === $hasPermissions) { goto B5d0f; } goto A6c8a; Ad1ec: B5d0f: goto F87d6; C10cb: $nodejsSettings = new NodejsSettingsEntity(); goto e76c8; E533a: A4564: goto dc500; d45c3: if (!(true === $request->isMethod("\x50\117\x53\124"))) { goto f5bf9; } goto Ad3e4; C79e3: } private function createNodejsSiteForm(NodejsSettingsEntity $nodejsSettings) : Form { goto D97dc; D7365: return $form; goto e611c; d7c1c: $form->add("\x73\165\142\x6d\x69\164", SubmitType::class, ["\141\164\164\x72" => ["\x63\154\x61\163\163" => "\142\164\156\x20\x62\164\156\55\154\147\x20\x62\164\x6e\x2d\x62\x6c\165\145"], "\154\x61\x62\145\x6c" => "\103\x72\145\141\x74\145"]); goto D7365; D97dc: $form = $this->createForm("\101\x70\x70\134\106\x6f\162\x6d\134\123\151\164\145\x4e\x65\x77\116\157\x64\x65\152\x73\x54\171\160\x65", $nodejsSettings, ["\x61\x63\164\x69\157\x6e" => $this->generateUrl("\143\154\x70\137\163\x69\x74\145\x5f\156\157\144\145\x6a\163\137\156\145\x77"), "\155\145\x74\x68\x6f\144" => "\120\117\x53\124", "\x61\164\x74\x72" => ["\151\x64" => "\x6e\145\167\x2d\156\157\x64\145\x6a\x73\x2d\x73\151\164\145\x2d\146\157\x72\155"]]); goto d7c1c; e611c: } private function handleCreateNodejsSiteForm(Request $request, Form $form) { goto fe289; fad2f: try { goto b1540; Fed80: if (false === is_null($vhostTemplateEntity)) { goto B6e5c; } goto be673; f0894: $this->createNodejsSite($domainName, $nodejsVersion, $port, $siteUser, $siteUserPassword); goto a84fb; b1540: $session = $request->getSession(); goto C05dd; C05dd: $domainName = $form->get("\x64\x6f\155\141\x69\x6e\116\141\155\145")->getData(); goto C664f; b4b9b: return $response; goto A57be; c3522: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Fed80; be673: throw new \Exception(sprintf("\x56\x68\x6f\163\164\40\164\145\155\x70\x6c\x61\164\x65\40\42\x25\x73\x22\x20\x6e\x6f\164\40\146\x6f\165\156\x64\x2e", $vhostTemplateName)); goto f1098; Ec3c5: $siteUser = $form->get("\x73\151\164\145\125\x73\x65\162")->getData(); goto Ea75d; Ea75d: $siteUserPassword = $form->get("\x73\151\164\145\125\163\x65\x72\120\141\163\163\167\x6f\x72\x64")->getData(); goto Aad69; afc9a: $user = $this->getUser(); goto f0894; b2021: B6e5c: goto afc9a; A57be: e014f: goto Be4f2; fc137: $port = $form->get("\x70\x6f\x72\x74")->getData(); goto Ec3c5; f1098: goto e014f; goto b2021; C664f: $nodejsVersion = $form->get("\x6e\157\144\x65\x6a\x73\126\x65\162\163\151\157\x6e")->getData(); goto fc137; a84fb: $eventData = ["\163\x69\164\145" => $domainName, "\163\x69\164\x65\125\163\x65\162" => $siteUser, "\156\x6f\144\145\152\163\x56\145\x72\163\x69\157\156" => $nodejsVersion, "\160\x6f\162\164" => $port]; goto Efbca; Aad69: $vhostTemplateName = self::NODEJS_VHOST_TEMPLATE_NAME; goto c3522; Ce235: $session->getFlashBag()->set("\x73\165\x63\x63\x65\163\163", $this->translator->trans("\x53\151\x74\145\x20\150\x61\163\x20\x62\x65\x65\x6e\x20\143\162\x65\141\164\145\x64\56")); goto c273b; c273b: $response = $this->redirect($this->generateUrl("\143\154\x70\x5f\x73\151\x74\145\163")); goto b4b9b; Efbca: EventQueue::addEvent(EventQueue::EVENT_SITE_NODEJS_CREATE, $user, $eventData, $request); goto Ce235; Be4f2: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\x6e\x67\x65\162", $this->translator->trans("\101\156\x20\145\x72\x72\x6f\x72\x20\150\141\163\40\x6f\x63\143\x75\x72\162\x65\x64\54\40\x65\162\162\157\x72\40\x6d\x65\163\163\x61\x67\145\x3a\40\x25\145\162\162\x6f\162\115\x65\163\x73\141\x67\x65\45", ["\45\145\x72\x72\x6f\x72\115\x65\x73\x73\x61\147\145\x25" => $e->getMessage()])); } goto F527a; ae86a: goto B867d; goto ae7c2; F527a: B867d: goto b45ab; fe289: if (true === $form->isValid()) { goto fd877; } goto B1be6; B1be6: $this->formErrors = $this->getErrorMessages($form); goto ae86a; ae7c2: fd877: goto fad2f; b45ab: } public function newStaticSite(Request $request) : Response { goto bb22d; E110c: efb5c: goto a7f59; e6ae7: d5fe1: goto F412f; F39c6: $user = $this->getUser(); goto a7c66; c4631: if (true === $hasPermissions) { goto C114a; } goto Afd50; Fd413: $response = $this->render("\106\162\157\x6e\x74\x65\x6e\x64\x2f\x53\151\164\x65\57\x4e\145\x77\x2f\x73\x74\x61\x74\151\x63\x2e\x68\164\155\x6c\x2e\164\x77\x69\x67", ["\165\x73\145\x72" => $user, "\x66\x6f\162\155" => $form->createView(), "\146\x6f\162\155\105\x72\x72\157\162\x73" => $this->formErrors]); goto e6ae7; d8010: if (!(true === $request->isMethod("\x50\x4f\123\x54"))) { goto Bf247; } goto d52b9; de982: cdd59: goto E110c; B6984: goto d5fe1; goto c4c7b; Afd50: $response = $this->redirect($this->generateUrl("\x63\154\x70\137\x73\x69\x74\145\163")); goto B6984; Ce5bc: return $response; goto de982; d52b9: $form->handleRequest($request); goto D763b; D763b: if (!(true === $form->isSubmitted())) { goto efb5c; } goto a656f; F412f: return $response; goto F1ec3; c077c: if (!(false === is_null($response))) { goto cdd59; } goto Ce5bc; a656f: $response = $this->handleCreateStaticSiteForm($request, $form); goto c077c; bb22d: $hasPermissions = $this->hasPermissions(); goto c4631; a7f59: Bf247: goto Fd413; a7c66: $form = $this->createStaticSiteForm(); goto d8010; c4c7b: C114a: goto F39c6; F1ec3: } private function createStaticSiteForm() : Form { goto b0334; E1340: return $form; goto Ace23; b0334: $form = $this->createForm("\x41\x70\x70\134\x46\x6f\162\155\x5c\x53\151\x74\x65\116\x65\x77\x53\164\x61\164\x69\x63\x54\x79\x70\145", [], ["\x61\143\x74\x69\x6f\156" => $this->generateUrl("\x63\x6c\160\137\x73\151\164\145\x5f\163\x74\141\164\151\143\137\x6e\x65\x77"), "\155\x65\164\150\x6f\x64" => "\x50\117\123\x54", "\141\x74\164\162" => []]); goto d81c9; d81c9: $form->add("\163\165\x62\155\151\x74", SubmitType::class, ["\141\x74\x74\x72" => ["\143\x6c\141\163\163" => "\142\x74\x6e\x20\142\164\x6e\55\154\x67\x20\142\164\x6e\x2d\142\154\165\x65"], "\154\x61\142\x65\154" => "\x43\x72\x65\x61\x74\x65"]); goto E1340; Ace23: } private function handleCreateStaticSiteForm(Request $request, Form $form) { goto d2c8b; F74ca: Dbfcc: goto f4c76; B9495: goto Dd763; goto F74ca; D80c5: Dd763: goto ed483; d2c8b: if (true === $form->isValid()) { goto Dbfcc; } goto a954f; f4c76: try { goto Decc4; Decc4: $session = $request->getSession(); goto E928f; Fc791: goto e3766; goto cf56a; f4257: $this->createStaticSite($domainName, $siteUser, $siteUserPassword); goto A215d; Dc0e6: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto C4c9b; a019c: return $response; goto Acb4d; Acb4d: e3766: goto f9d36; A215d: $eventData = ["\163\x69\x74\145" => $domainName, "\x73\151\x74\x65\125\163\x65\162" => $siteUser]; goto f0bea; Ce7be: $session->getFlashBag()->set("\163\165\x63\x63\x65\x73\x73", $this->translator->trans("\x53\151\x74\145\x20\150\141\x73\40\x62\x65\145\x6e\x20\143\162\x65\x61\x74\x65\x64\56")); goto C235d; C4c9b: if (false === is_null($vhostTemplateEntity)) { goto Fa0e7; } goto dfa00; dfa00: throw new \Exception(sprintf("\126\x68\157\x73\164\40\x74\x65\155\x70\x6c\x61\x74\145\40\x22\x25\163\x22\x20\156\x6f\164\x20\x66\x6f\x75\x6e\144\56", $vhostTemplateName)); goto Fc791; ec754: $vhostTemplateName = self::STATIC_SITE_VHOST_TEMPLATE_NAME; goto Dc0e6; E928f: $domainName = $form->get("\144\157\155\x61\x69\156\x4e\x61\x6d\145")->getData(); goto ae5a3; f0bea: EventQueue::addEvent(EventQueue::EVENT_SITE_STATIC_CREATE, $user, $eventData, $request); goto Ce7be; ae5a3: $siteUser = $form->get("\x73\x69\164\x65\x55\163\145\x72")->getData(); goto c34cb; C235d: $response = $this->redirect($this->generateUrl("\143\x6c\160\x5f\163\x69\164\x65\163")); goto a019c; c34cb: $siteUserPassword = $form->get("\163\x69\x74\x65\125\163\145\x72\x50\141\163\163\167\x6f\162\x64")->getData(); goto ec754; cf56a: Fa0e7: goto bb1db; bb1db: $user = $this->getUser(); goto f4257; f9d36: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\x6e\x67\x65\x72", $this->translator->trans("\101\156\x20\x65\162\162\157\x72\x20\x68\141\163\x20\157\143\x63\x75\x72\162\145\x64\x2c\x20\x65\x72\x72\157\x72\40\x6d\145\163\163\141\x67\145\x3a\40\45\145\x72\162\157\x72\115\x65\x73\163\x61\147\x65\x25", ["\x25\145\x72\x72\157\162\x4d\x65\163\x73\x61\x67\145\45" => $e->getMessage()])); } goto D80c5; a954f: $this->formErrors = $this->getErrorMessages($form); goto B9495; ed483: } public function newPhpSite(Request $request) : Response { goto cbf70; dabec: if (!(false === is_null($response))) { goto b1c23; } goto eaeea; Baaab: goto fd9d1; goto B4ef4; Ec838: $response = $this->handleCreatePhpSiteForm($request, $form); goto dabec; a6278: $form->handleRequest($request); goto eb92c; C7c71: fd9d1: goto Ced7e; eaeea: return $response; goto E0f93; B4ef4: ae9c7: goto a7512; cbf70: $hasPermissions = $this->hasPermissions(); goto d3f68; E0f93: b1c23: goto E23bd; Ced7e: return $response; goto b90a8; E23bd: C8646: goto d6d24; a7512: $user = $this->getUser(); goto e754c; d3f68: if (true === $hasPermissions) { goto ae9c7; } goto Cc54d; Cc54d: $response = $this->redirect($this->generateUrl("\x63\154\160\137\163\151\x74\145\x73")); goto Baaab; d6d24: f3178: goto dd62d; eb92c: if (!(true === $form->isSubmitted())) { goto C8646; } goto Ec838; e754c: $form = $this->createPhpSiteForm(); goto D8b5b; D8b5b: if (!(true === $request->isMethod("\x50\x4f\123\x54"))) { goto f3178; } goto a6278; dd62d: $response = $this->render("\x46\x72\157\x6e\164\145\x6e\x64\x2f\123\x69\x74\145\57\x4e\x65\x77\57\160\x68\x70\x2e\x68\x74\x6d\x6c\56\164\167\151\x67", ["\165\163\x65\162" => $user, "\x66\x6f\162\155" => $form->createView(), "\146\x6f\162\155\105\x72\x72\157\x72\x73" => $this->formErrors]); goto C7c71; b90a8: } private function createPhpSiteForm() : Form { goto Cd959; Cd959: $form = $this->createForm("\x41\160\160\x5c\106\x6f\162\x6d\x5c\x53\x69\x74\x65\116\x65\x77\120\150\x70\124\171\160\x65", [], ["\x61\x63\x74\x69\157\156" => $this->generateUrl("\x63\x6c\160\137\x73\x69\164\x65\x5f\x70\x68\160\x5f\x6e\145\167"), "\155\x65\164\x68\157\x64" => "\x50\x4f\123\124", "\x61\x74\x74\x72" => []]); goto Aafe6; beb23: return $form; goto E6861; Aafe6: $form->add("\163\x75\x62\x6d\151\x74", SubmitType::class, ["\x61\x74\164\x72" => ["\x63\x6c\x61\163\163" => "\142\164\x6e\x20\142\x74\156\55\x6c\147\x20\142\164\x6e\x2d\x62\154\165\145"], "\x6c\x61\142\145\x6c" => "\103\162\145\141\x74\x65"]); goto beb23; E6861: } private function handleCreatePhpSiteForm(Request $request, Form $form) { goto Ce624; E13d9: $this->formErrors = $this->getErrorMessages($form); goto d4733; F247a: try { goto F6d75; d5058: $response = $this->redirect($this->generateUrl("\143\x6c\160\x5f\163\151\164\x65\x73")); goto e2dd9; D4cb1: $eventData = ["\x73\x69\x74\145" => $domainName, "\166\x68\157\163\164\x54\145\155\160\154\x61\164\x65\x4e\x61\x6d\145" => $vhostTemplateName, "\x70\x68\160\126\x65\x72\163\x69\x6f\x6e" => $phpVersion, "\x73\x69\x74\145\125\163\145\x72" => $siteUser]; goto C09b2; D902f: $rootDirectory = $domainName; goto f7224; d23ce: $user = $this->getUser(); goto D902f; Fbb90: $siteUser = $form->get("\163\x69\164\145\125\163\x65\162")->getData(); goto Fa91d; C0817: $vhostTemplateName = $form->get("\x61\x70\160\x6c\x69\x63\141\164\x69\x6f\156")->getData(); goto e30d6; Ad357: if (false === is_null($vhostTemplateEntity)) { goto d8ba7; } goto Bf4bb; bd76d: d8ba7: goto d23ce; a796c: $session->getFlashBag()->set("\x73\x75\x63\143\x65\163\163", $this->translator->trans("\123\151\x74\x65\40\x68\x61\163\x20\142\x65\x65\156\x20\x63\x72\145\141\x74\x65\144\x2e")); goto d5058; Ae6c7: goto f0a47; goto bd76d; f7224: if (!(false === empty($vhostTemplateEntity->getRootDirectory()))) { goto E94f1; } goto B08b0; Fa91d: $siteUserPassword = $form->get("\163\151\x74\x65\125\163\x65\x72\120\x61\x73\163\167\157\162\144")->getData(); goto e3d41; e2dd9: return $response; goto F31b2; F31b2: f0a47: goto b49e1; e30d6: $domainName = $form->get("\x64\x6f\155\x61\151\156\116\141\155\145")->getData(); goto Ca67d; Ed5e8: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto e0b8c; F6d75: $session = $request->getSession(); goto C0817; A265c: E94f1: goto bdb65; e3d41: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Ad357; e0b8c: d3e3b: goto fbc85; B08b0: $rootDirectory = sprintf("\45\x73\57\x25\163", $rootDirectory, ltrim(rtrim($vhostTemplateEntity->getRootDirectory(), "\57"), "\x2f")); goto A265c; bdb65: $varnishCacheSettings = []; goto e0cac; fbc85: $this->createPhpSite($domainName, $rootDirectory, $phpVersion, $vhostTemplateName, $siteUser, $siteUserPassword, $varnishCacheSettings); goto D4cb1; C09b2: EventQueue::addEvent(EventQueue::EVENT_SITE_PHP_CREATE, $user, $eventData, $request); goto a796c; Ca67d: $phpVersion = $form->get("\x70\x68\x70\x56\x65\x72\x73\x69\157\x6e")->getData(); goto Fbb90; e0cac: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto d3e3b; } goto Ed5e8; Bf4bb: throw new \Exception(sprintf("\126\150\x6f\163\x74\x20\164\x65\x6d\x70\154\x61\x74\145\40\42\45\163\x22\x20\156\x6f\164\40\x66\x6f\x75\x6e\x64\x2e", $vhostTemplateName)); goto Ae6c7; b49e1: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\x6e\x67\x65\x72", $this->translator->trans("\101\156\40\145\162\162\x6f\162\40\150\141\163\40\x6f\143\143\x75\162\162\145\144\x2c\x20\145\x72\x72\x6f\x72\40\155\x65\x73\x73\x61\x67\145\72\40\45\x65\x72\162\157\162\115\x65\163\163\x61\x67\145\x25", ["\x25\145\162\x72\157\162\115\145\x73\x73\x61\147\x65\x25" => $e->getMessage()])); } goto d2374; d4733: goto F8e9e; goto fecf6; Ce624: if (true === $form->isValid()) { goto c1c99; } goto E13d9; fecf6: c1c99: goto F247a; d2374: F8e9e: goto ccc77; ccc77: } public function newWordPressSite(Request $request) : Response { goto b3683; F0a83: e18e3: goto b4538; ec9c5: $user = $this->getUser(); goto F8ac2; F8ac2: $form = $this->createWordPressSiteForm(); goto Ac425; Ac425: if (!(true === $request->isMethod("\x50\117\123\x54"))) { goto e18e3; } goto d3306; Bfdd1: if (true === $hasPermissions) { goto Db499; } goto a2b7f; C9e23: Db499: goto ec9c5; d3306: $form->handleRequest($request); goto cdf4e; b5aa3: $response = $this->handleCreateWordPressSiteForm($request, $form); goto ac9ef; Cf200: return $response; goto bf499; ab300: goto B5f94; goto C9e23; Fc642: a6b51: goto F0a83; b7432: Afd74: goto Fc642; b3683: $hasPermissions = $this->hasPermissions(); goto Bfdd1; a2b7f: $response = $this->redirect($this->generateUrl("\143\154\x70\137\x73\151\164\145\x73")); goto ab300; C17ae: B5f94: goto Cf200; b4538: $response = $this->render("\106\x72\157\156\x74\145\x6e\x64\57\x53\x69\164\x65\x2f\x4e\145\x77\x2f\x77\x6f\162\x64\160\162\145\163\x73\56\150\x74\x6d\x6c\x2e\164\167\x69\x67", ["\x75\x73\145\162" => $user, "\146\157\162\x6d" => $form->createView(), "\x66\x6f\162\x6d\x45\162\x72\157\162\163" => $this->formErrors]); goto C17ae; ac9ef: if (!(false === is_null($response))) { goto Afd74; } goto b96cd; cdf4e: if (!(true === $form->isSubmitted())) { goto a6b51; } goto b5aa3; b96cd: return $response; goto b7432; bf499: } private function createWordPressSiteForm() : Form { goto C8f14; cced5: return $form; goto B8e8a; C8f14: $form = $this->createForm("\101\x70\160\134\106\x6f\x72\x6d\134\x53\x69\164\x65\116\x65\167\127\x6f\162\x64\120\x72\145\x73\163\x54\171\x70\145", [], ["\141\143\164\x69\157\156" => $this->generateUrl("\143\154\x70\x5f\x73\x69\x74\x65\137\x77\x6f\x72\144\160\162\x65\x73\x73\137\x6e\145\167"), "\x6d\145\x74\150\157\x64" => "\120\117\x53\124", "\x61\x74\x74\x72" => ["\151\x64" => "\156\145\167\55\167\157\162\x64\x70\162\145\x73\163\x2d\x73\151\164\x65\55\x66\x6f\162\x6d"]]); goto a62ba; a62ba: $form->add("\x73\x75\142\x6d\x69\x74", SubmitType::class, ["\141\164\x74\162" => ["\143\154\141\163\x73" => "\x62\x74\156\x20\142\x74\x6e\55\154\147\40\x62\x74\x6e\55\x62\154\165\x65"], "\154\141\142\145\x6c" => "\103\162\145\x61\164\145"]); goto cced5; B8e8a: } private function handleCreateWordPressSiteForm(Request $request, Form $form) { goto F71ee; c8c7f: Bea82: goto Fd51e; c0c17: B7a37: goto db436; Be780: goto B7a37; goto c8c7f; e4a7e: $this->formErrors = $this->getErrorMessages($form); goto Be780; Fd51e: try { goto c2e67; C1c89: $session = $request->getSession(); goto D81dc; a5bc4: EventQueue::addEvent(EventQueue::EVENT_SITE_WORDPRESS_CREATE, $user, $eventData, $request); goto ff14e; Bf6fe: $databaseEntity->setDatabaseServer($activeDatabaseServerEntity); goto bcd20; Efb58: $url = sprintf("\x68\164\x74\160\163\x3a\57\57\x25\x73", $siteEntity->getDomainName()); goto D37c9; E9862: $instance = $request->attributes->get("\x69\x6e\163\164\141\156\x63\x65"); goto E572a; c2e67: $user = $this->getUser(); goto C1c89; D0432: A9cc4: goto f1c12; Cf821: $databaseManager = new DatabaseManager($activeDatabaseServerEntity); goto E301a; A7d85: $varnishCacheSettings = []; goto F56b3; dfd0f: $databaseUserName = $this->getUniqueDatabaseUserName($generatedName); goto C8313; a42cd: $eventData = ["\x73\151\x74\145" => $domainName, "\163\151\x74\x65\125\x73\145\162" => $siteUser]; goto a5bc4; b683c: $siteEntity->addDatabase($databaseEntity); goto Cf821; e725c: $databaseEntity = $this->databaseEntityManager->createEntity(); goto Bf6fe; B0920: $this->installWordPress($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail, $siteEntity, $activeDatabaseServerEntity, $databaseEntity, $databaseUserEntity); goto Ccdb3; F9f22: $generatedName = $this->generateNameFromDomainName($domainName); goto fdeba; B12b0: $databaseEntity->setSite($siteEntity); goto Ae5f7; E572a: $siteCredentials = [$this->translator->trans("\123\x69\164\x65") => [$this->translator->trans("\x49\120\x20\x41\x64\144\162\145\163\x73") => $instance->getIpv4PublicIp(), $this->translator->trans("\x44\157\x6d\x61\151\x6e\40\x4e\x61\x6d\145") => sprintf("\x68\164\164\x70\x73\x3a\x2f\57\45\163", $domainName), $this->translator->trans("\123\x69\164\145\40\x55\163\x65\162") => $siteUser, $this->translator->trans("\120\141\163\x73\167\x6f\162\x64") => $siteUserPassword]]; goto e8905; f1c12: $siteEntity = $this->createPhpSite($domainName, $domainName, $phpVersion, self::WORDPRESS_VHOST_TEMPLATE_NAME, $siteUser, $siteUserPassword, $varnishCacheSettings); goto c9df6; A24a4: $siteCredentials["\127\157\162\x64\120\x72\x65\x73\163"] = [$this->translator->trans("\x41\x64\x6d\151\156\40\x45\55\115\x61\151\154") => $adminEmail, $this->translator->trans("\x41\144\x6d\x69\156\x20\x55\x73\x65\162\40\116\141\x6d\145") => $adminUserName, $this->translator->trans("\101\x64\155\151\x6e\40\120\x61\x73\163\167\157\x72\144") => $adminPassword, $this->translator->trans("\101\x64\155\x69\x6e\40\x55\162\x6c") => sprintf("\x68\164\164\160\x73\x3a\57\57\45\163\x2f\167\x70\x2d\141\144\x6d\151\156\x2f", rtrim($domainName, "\x2f"))]; goto A488a; D37c9: $title = $form->get("\x73\x69\164\x65\x54\x69\164\x6c\x65")->getData(); goto f7618; E2793: $databaseUserEntity->setPassword(Crypto::encrypt($databaseUserPassword)); goto Bf355; Be035: $phpVersion = $vhostTemplateEntity->getPhpVersion(); goto A7d85; E301a: $databaseManager->createDatabase($databaseEntity); goto F3e02; ef32a: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto e725c; e8905: if (!(false === is_null($siteEntity))) { goto B1960; } goto Bd1b7; F56b3: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto A9cc4; } goto D510f; Bd1b7: $databaseName = $this->getUniqueDatabaseName($generatedName); goto dfd0f; Ccdb3: $siteCredentials[$this->translator->trans("\x44\x61\x74\x61\x62\x61\163\x65")] = [$this->translator->trans("\x48\157\163\x74") => $activeDatabaseServerEntity->getHost(), $this->translator->trans("\x50\157\162\x74") => $activeDatabaseServerEntity->getPort(), $this->translator->trans("\x44\x61\x74\x61\x62\x61\163\145\x20\x4e\x61\155\x65") => $databaseName, $this->translator->trans("\x44\141\164\141\x62\x61\163\x65\x20\x55\163\145\162\40\x4e\x61\155\145") => $databaseUserName, $this->translator->trans("\104\141\164\141\x62\141\x73\145\40\125\163\145\162\x20\120\x61\163\x73\167\x6f\162\144") => $databaseUserPassword]; goto A24a4; Afc69: $this->siteEntityManager->updateEntity($siteEntity); goto B0920; fdeba: $siteUser = $form->get("\163\151\x74\x65\x55\x73\145\x72")->getData(); goto Df9fb; Bf355: $databaseUserEntity->setPermissions(DatabaseUserEntity::PERMISSIONS_READ_WRITE); goto fc92d; d1d89: $adminPassword = $form->get("\141\144\x6d\x69\x6e\120\141\x73\x73\x77\157\162\x64")->getData(); goto Fd5e0; fc92d: $databaseUserEntity->setDatabase($databaseEntity); goto F3987; D81dc: $domainName = $form->get("\144\x6f\155\x61\x69\156\116\x61\x6d\145")->getData(); goto F9f22; A488a: B1960: goto d5edc; ff14e: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\137\163\x69\x74\x65\137\167\157\162\144\160\162\145\x73\163\x5f\151\x6e\163\x74\x61\x6c\x6c\145\x64")); goto E0131; Bd668: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::WORDPRESS_VHOST_TEMPLATE_NAME); goto Be035; d5edc: $session->set("\163\x69\x74\x65\x43\162\145\144\145\x6e\164\x69\x61\154\x73", $siteCredentials); goto a42cd; bcd20: $databaseEntity->setName($databaseName); goto B12b0; A98dd: $isMultiSite = $form->get("\155\165\154\164\x69\123\x69\x74\x65")->getData(); goto ef32a; F3987: $databaseEntity->addUser($databaseUserEntity); goto b683c; cd1ed: $databaseUserEntity->setUserName($databaseUserName); goto E2793; f7618: $adminUserName = $form->get("\x61\144\x6d\x69\x6e\125\163\x65\162\x4e\141\155\x65")->getData(); goto d1d89; Df9fb: $siteUserPassword = $form->get("\163\x69\164\x65\125\x73\145\162\x50\x61\163\163\167\x6f\162\144")->getData(); goto Bd668; F3e02: $databaseManager->createUser($databaseUserEntity); goto Afc69; Fd5e0: $adminEmail = $form->get("\141\x64\155\x69\x6e\105\155\141\151\154")->getData(); goto A98dd; C8313: $databaseUserPassword = PasswordGenerator::generate(self::PASSWORD_LENGTH); goto Efb58; Ae5f7: $databaseUserEntity = $this->databaseUserEntityManager->createEntity(); goto cd1ed; E0131: return $response; goto d1a85; D510f: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto D0432; c9df6: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto E9862; d1a85: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\x6e\147\x65\162", $this->translator->trans("\101\x6e\40\x65\x72\x72\157\162\x20\150\141\163\40\157\143\x63\x75\x72\162\145\x64\x2c\x20\145\162\162\x6f\162\x20\155\145\163\x73\141\x67\x65\x3a\x20\45\145\162\162\157\162\115\145\163\x73\141\147\145\x25", ["\45\x65\162\162\x6f\x72\x4d\145\163\163\x61\x67\x65\45" => $e->getMessage()])); } goto c0c17; F71ee: if (true === $form->isValid()) { goto Bea82; } goto e4a7e; db436: } private function installWordPress(bool $isMultiSite, string $url, string $title, string $adminUserName, string $adminPassword, string $adminEmail, SiteEntity $siteEntity, DatabaseServerEntity $databaseServerEntity, DatabaseEntity $databaseEntity, DatabaseUserEntity $databaseUserEntity) : void { goto D8ed8; da863: F587e: goto d68ba; E289f: $databaseName = $databaseEntity->getName(); goto a86ee; a86ee: $databaseUserName = $databaseUserEntity->getUserName(); goto D8075; Ee9d3: foreach ($this->wordPressDefaultConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\x76\141\x6c\165\x65"], $config["\x72\141\167"]); D7d05: } goto c037e; e20d6: $wordPressInstaller = new WordPressInstaller($siteEntity); goto Caf57; Fb90d: $wordPressInstaller->resetPermissions(); goto E9879; c037e: e150d: goto D811a; d68ba: D7cb6: goto Fb90d; aade3: $this->wordPressMultiSiteConfigValues["\104\117\x4d\x41\x49\x4e\137\x43\x55\122\122\105\x4e\124\137\x53\111\x54\x45"]["\x76\141\154\x75\x65"] = $siteEntity->getDomainName(); goto b4859; D811a: if (!(true === $isMultiSite)) { goto D7cb6; } goto aade3; Af444: $wordPressInstaller->createConfig($databaseHost, $databaseName, $databaseUserName, $databaseUserPassword); goto a5980; Caf57: $wordPressInstaller->downloadAndExtractLatestVersion(); goto Af444; a5980: $wordPressInstaller->installCore($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail); goto Ee9d3; D8ed8: $databaseHost = sprintf("\x25\163\x3a\x25\163", $databaseServerEntity->getHost(), $databaseServerEntity->getPort()); goto E289f; b4859: foreach ($this->wordPressMultiSiteConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\x76\141\154\165\145"], $config["\x72\141\167"]); fc157: } goto da863; D8075: $databaseUserPassword = Crypto::decrypt($databaseUserEntity->getPassword()); goto e20d6; E9879: } private function createPhpSite(string $domainName, string $rootDirectory, string $phpVersion, string $vhostTemplateName, string $siteUser, string $siteUserPassword, array $varnishCacheSettings = []) : SiteEntity { goto d59b8; bc9d3: $phpSiteCreator->createNginxVhost(); goto dccfc; b0093: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto Bbd3b; e8f61: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto F0b6b; Dacb1: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto cf9ae; ba9b6: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto edac7; a687a: if (true === isset($_ENV["\101\x50\x50\137\110\124\124\x50\x33"]) && "\x74\x72\x75\x65" === $_ENV["\101\120\120\x5f\x48\x54\x54\120\63"]) { goto D662c; } goto ef9f6; bc935: $phpSite->setUser($siteEntity->getUser()); goto c22f1; cb4a0: $siteEntity->setCertificate($certificateEntity); goto bdbad; a1201: $vhostTemplate->build(); goto b1969; cd5f7: $phpSite->setRegistrableDomain($registrableDomain); goto cfc46; Efbb6: F5bf5: goto Aa337; bd721: $subjectAlternativeNames[] = sprintf("\x77\x77\167\x2e\45\x73", $domainName); goto badd2; Df334: if (!(false === is_null($subdomain) && "\x77\167\167" == $subdomain)) { goto a2a27; } goto c6945; d23a9: $varnishCacheSettings = array_merge($defaultVarnishCacheSettings, $varnishCacheSettings); goto D77e9; d8c9d: $rootDirectory = trim(rtrim(ltrim($rootDirectory, "\57")), "\x2f"); goto Acd3b; badd2: e903c: goto Df334; fb00c: if (!(false === empty($varnishCache))) { goto Bbd71; } goto c66cf; ea7f7: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\x2f\x2e\56\x2f\x2e\x2e\x2f\162\145\163\157\165\162\x63\145\x73\x2f\x6e\x67\151\x6e\170\x2f\x76\x68\157\x73\x74\137\164\145\155\160\154\x61\x74\x65\x2f\x72\x65\x64\x69\162\145\x63\x74\x2d\150\164\164\160\x33"); goto ddc17; Efdd7: $phpSiteCreator->createPrivateKeyAndCertificate(); goto ec3f4; d7b56: $phpSettingsEntity->setSite($siteEntity); goto B695e; e4152: $phpSiteCreator->resetPermissions(); goto dd34e; a602b: goto Fdf66; goto F4cfc; F3af5: if (!(count($siteConstraints) || count($phpSettingsConstraints))) { goto F6e87; } goto e20ea; c7dcd: $phpSite->setPhpSettings($phpSettingsEntity); goto Fff73; D9573: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto c8463; abe0b: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto C63df; Db095: $constraintViolationList->addAll($phpSettingsConstraints); goto ae406; d97e9: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto Dacb1; bdbad: $phpSite = new PhpSite(); goto bc935; fc66a: d494b: goto bc9d3; b7389: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto cfedf; d59b8: $varnishCache = false === empty($varnishCacheSettings) ? true : false; goto d8c9d; f4b50: $phpSite->setDomainName($domainName); goto cd5f7; d6dec: $phpSite->setCertificate($certificateEntity); goto c7dcd; edefa: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Aab6d; bae9d: $siteEntity->setPhpSettings($phpSettingsEntity); goto F3c52; ef9f6: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\56\57\56\x2e\57\56\56\57\x72\x65\163\157\165\x72\x63\x65\163\x2f\156\x67\151\156\170\x2f\166\x68\157\x73\x74\137\x74\x65\155\x70\154\141\x74\145\x2f\162\145\x64\x69\162\145\x63\164"); goto a602b; e20ea: $constraintViolationList = new ConstraintViolationList(); goto a6e8b; c61a0: throw new \Exception(implode("\73\x20", $errorMessages)); goto Fc65f; A2762: $phpSettingsConstraints = $this->validator->validate($phpSettingsEntity); goto F3af5; dd34e: $vhostTemplate = new PhpVhostTemplate($phpSite); goto abe0b; F6fa1: $phpSiteCreator->reloadPhpFpmService(); goto A2986; Bbd3b: $this->siteEntityManager->updateEntity($siteEntity); goto ad769; A0de3: $phpSiteCreator->createLogrotateFile(); goto B52f5; eac27: $phpSiteCreator->createRootDirectory(); goto A0de3; cfedf: $siteEntity = $this->siteEntityManager->createEntity(); goto ea722; ec3f4: $phpSiteCreator->createPhpFpmPool(); goto F6fa1; Aa337: $siteEntity->setVhostTemplate($vhostTemplate); goto Bf1a7; A4051: $certificateEntity->setCertificate($selfSignedCertificate); goto cb4a0; Bf1a7: $phpSettingsEntity = new PhpSettingsEntity(); goto bae9d; Bbf43: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto C2d8e; e22c7: if (!(true === is_null($subdomain))) { goto e903c; } goto bd721; f6986: $csr = $csrGenerator->generate(); goto Bbf43; c6945: $subjectAlternativeNames[] = $registrableDomain; goto bf27c; c8463: $subdomain = $resolvedDomainName->subDomain()->toString(); goto ef22b; def89: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto A4051; f09a5: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto b7389; eda9e: $defaultVarnishCacheSettings = ["\145\x6e\x61\x62\154\x65\144" => false, "\x73\x65\162\x76\145\x72" => self::VARNISH_CACHE_SERVER, "\x63\141\x63\x68\x65\x54\141\x67\120\x72\145\146\151\x78" => substr(md5(time()), 0, 4)]; goto d23a9; Fc65f: F6e87: goto edefa; Aab6d: $certificateEntity->setSite($siteEntity); goto d7d7f; edac7: $certificateEntity->setCsr($csr); goto def89; dccfc: $phpSiteCreator->reloadNginxService(); goto e4152; B52f5: $phpSiteCreator->createIndexPhp(); goto Efdd7; e5d13: $phpSite->setRootDirectory($siteEntity->getRootDirectory()); goto d6dec; d7d7f: $rsaKeyGenerator = new RsaKeyGenerator(); goto eba92; Cc214: $siteEntity->setRootDirectory($rootDirectory); goto fb00c; ddc17: Fdf66: goto e4d51; Bcc4c: if (!(false === empty($redirectionVhostTemplate))) { goto bd0bd; } goto a0c0c; a0c0c: $vhostTemplate = sprintf("\45\163\x25\x73", $redirectionVhostTemplate, $vhostTemplate); goto ded93; ded93: bd0bd: goto Efbb6; ad769: return $siteEntity; goto a7f9c; F3c52: $phpSettingsEntity->setPhpVersion($phpVersion); goto d7b56; bf27c: a2a27: goto e8f61; d5159: if (!(true === is_null($subdomain) || "\167\x77\167" == $subdomain)) { goto F5bf5; } goto a687a; a6e8b: $constraintViolationList->addAll($siteConstraints); goto Db095; ef22b: $subdomain = false === empty($subdomain) ? $subdomain : null; goto f09a5; c5f7b: $siteEntity->setUser($siteUser); goto F507c; ea722: $siteEntity->setType(SiteEntity::TYPE_PHP); goto Ab2cc; d629a: Bbd71: goto d5159; e4d51: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto Bcc4c; C63df: $vhostTemplate->resetProcessors(); goto d97e9; F507c: $siteEntity->setUserPassword($siteUserPassword); goto Cc214; F0b6b: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto f6986; f1b34: $phpSite->setVarnishCacheSettings($varnishCacheSettings); goto fc66a; d7d5c: $phpSite->setVarnishCache(true); goto eda9e; a02bc: $phpSiteCreator = new PhpSiteCreator($phpSite); goto Bbcfa; Acd3b: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto D9573; cfc46: $phpSite->setSubdomain($subdomain); goto e5d13; ae406: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto c61a0; Bbcfa: $phpSiteCreator->createUser(); goto eac27; F4cfc: D662c: goto ea7f7; C2d8e: $certificateEntity->setDefaultCertificate(true); goto ba9b6; D77e9: $phpSiteCreator->createVarnishCacheStructure($varnishCacheSettings); goto f1b34; cf9ae: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto a1201; Fff73: $phpSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto a02bc; c22f1: $phpSite->setUserPassword($siteEntity->getUserPassword()); goto f4b50; eba92: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto D3624; Ab2cc: $siteEntity->setDomainName($domainName); goto c5f7b; D3624: $subjectAlternativeNames = []; goto e22c7; B695e: $siteConstraints = $this->validator->validate($siteEntity); goto A2762; c66cf: $siteEntity->setVarnishCache(true); goto d629a; A2986: if (!(true === $varnishCache)) { goto d494b; } goto d7d5c; b1969: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto b0093; a7f9c: } private function createNodejsSite(string $domainName, string $nodejsVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto Ccd36; A6eb8: $vhostTemplate->resetProcessors(); goto E6e20; cda0e: $this->siteEntityManager->updateEntity($siteEntity); goto c8164; d19e3: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\x2e\57\x2e\56\57\56\56\x2f\x72\145\x73\x6f\x75\162\x63\x65\x73\57\x6e\147\x69\x6e\170\57\166\150\x6f\163\164\137\164\145\155\x70\x6c\x61\x74\145\57\x72\x65\144\x69\x72\x65\143\x74\x2d\x68\x74\164\160\63"); goto b0fcd; e4f3e: $siteEntity->setUserPassword($siteUserPassword); goto c1cba; cccdc: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto ed4b8; E1303: $vhostTemplate->build(); goto eed38; F1ae9: $nodejsSite->setUserPassword($siteEntity->getUserPassword()); goto e4fa8; ff193: $nodejsSite->setRegistrableDomain($registrableDomain); goto f9b61; E479b: $constraintViolationList->addAll($nodejsSettingsConstraints); goto cccdc; f0b89: if (true === isset($_ENV["\101\120\x50\x5f\x48\x54\124\120\x33"]) && "\164\x72\165\145" === $_ENV["\x41\120\x50\137\x48\x54\124\120\x33"]) { goto A35fe; } goto A40e4; b521d: $nodejsSiteCreator->createUser(); goto D3b4b; aba39: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto Cc00d; f7c69: $nodejsSiteCreator->createLogrotateFile(); goto Def0c; D3b4b: $nodejsSiteCreator->createRootDirectory(); goto f7c69; a3bf9: $nodejsSettingsEntity->setPort($port); goto Ee88b; e59fa: $nodejsSite->setRootDirectory($siteEntity->getRootDirectory()); goto f84ea; afa5b: $nodejsSettingsEntity->setNodejsVersion($nodejsVersion); goto a3bf9; ee3b8: $subdomain = false === empty($subdomain) ? $subdomain : null; goto c793a; aa344: $siteConstraints = $this->validator->validate($siteEntity); goto e21ad; e4531: if (!(false === is_null($subdomain) && "\167\x77\167" == $subdomain)) { goto a838b; } goto c64bd; b0fcd: B4e68: goto c1d9b; c59df: $nodejsSiteCreator->createNginxVhost(); goto E917d; bde41: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto B029a; f0462: afaea: goto B6e13; d3683: if (!(true === is_null($subdomain) || "\x77\167\x77" == $subdomain)) { goto B842c; } goto f0b89; f8fe1: $subjectAlternativeNames[] = sprintf("\167\167\x77\56\x25\x73", $domainName); goto F6a56; Def0c: $nodejsSiteCreator->createNvmDirectory(); goto c5ace; c7e14: $certificateEntity = $this->certificateEntityManager->createEntity(); goto Ae9de; e0cce: if (!(false === empty($redirectionVhostTemplate))) { goto afaea; } goto Adcc6; Afb8b: $nodejsSiteCreator->createPrivateKeyAndCertificate(); goto c59df; B029a: $subdomain = $resolvedDomainName->subDomain()->toString(); goto ee3b8; Fff93: $certificateEntity->setCertificate($selfSignedCertificate); goto faf6c; c64bd: $subjectAlternativeNames[] = $registrableDomain; goto Eb123; Cc00d: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto B6f8c; B6f8c: $csr = $csrGenerator->generate(); goto d7652; f84ea: $nodejsSite->setCertificate($certificateEntity); goto d88a0; D56fa: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto ce5f0; b4196: $siteEntity->setNodejsSettings($nodejsSettingsEntity); goto afa5b; d88a0: $nodejsSite->setNodejsSettings($nodejsSettingsEntity); goto E3b23; ce7ac: goto B4e68; goto f560b; F6a56: Fdfd1: goto e4531; A40e4: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\x2f\x2e\56\x2f\56\56\x2f\x72\x65\x73\x6f\165\162\143\145\x73\57\156\x67\151\156\170\x2f\x76\150\157\163\x74\137\x74\145\155\160\154\x61\164\x65\x2f\x72\x65\x64\151\162\145\x63\x74"); goto ce7ac; f9b61: $nodejsSite->setSubdomain($subdomain); goto e59fa; A5270: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto f0209; af738: $constraintViolationList->addAll($siteConstraints); goto E479b; Bdc0e: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto cda0e; c8164: return $siteEntity; goto Ce27c; eed38: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Bdc0e; d0a69: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto A6eb8; Ff356: $nodejsSite->setUser($siteEntity->getUser()); goto F1ae9; Eb123: a838b: goto aba39; c5ace: $nodejsSiteCreator->installNodejs(); goto Afb8b; e4fa8: $nodejsSite->setDomainName($domainName); goto ff193; E57f4: a24b2: goto c7e14; ce5f0: $siteEntity = $this->siteEntityManager->createEntity(); goto b1760; Ae9de: $certificateEntity->setSite($siteEntity); goto a1e0a; E6e20: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto a39b3; Bc4f0: $certificateEntity->setDefaultCertificate(true); goto E8265; E917d: $nodejsSiteCreator->reloadNginxService(); goto E22bd; B6e13: B842c: goto A9562; f0a70: $constraintViolationList = new ConstraintViolationList(); goto af738; E3b23: $nodejsSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto D0b08; c808c: $nodejsSite = new NodejsSite(); goto Ff356; A9562: $siteEntity->setVhostTemplate($vhostTemplate); goto cca3b; E8265: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto Bc714; E22bd: $nodejsSiteCreator->resetPermissions(); goto F6fae; Ccd36: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto bde41; f0209: $subjectAlternativeNames = []; goto cc221; Adcc6: $vhostTemplate = sprintf("\x25\x73\45\163", $redirectionVhostTemplate, $vhostTemplate); goto f0462; c1d9b: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto e0cce; D6f74: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto E1303; B5e81: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto Fff93; c1cba: $siteEntity->setRootDirectory($domainName); goto d3683; cc221: if (!(true === is_null($subdomain))) { goto Fdfd1; } goto f8fe1; e21ad: $nodejsSettingsConstraints = $this->validator->validate($nodejsSettingsEntity); goto b6ab3; c793a: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::NODEJS_VHOST_TEMPLATE_NAME); goto D56fa; Bc714: $certificateEntity->setCsr($csr); goto B5e81; c5ef5: $siteEntity->setUser($siteUser); goto e4f3e; D98a8: $siteEntity->setDomainName($domainName); goto c5ef5; F6fae: $vhostTemplate = new StaticVhostTemplate($nodejsSite); goto d0a69; D0b08: $nodejsSiteCreator = new NodejsSiteCreator($nodejsSite); goto b521d; d7652: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto Bc4f0; b6ab3: if (!(count($siteConstraints) || count($nodejsSettingsConstraints))) { goto a24b2; } goto f0a70; b1760: $siteEntity->setType(SiteEntity::TYPE_NODEJS); goto D98a8; cca3b: $nodejsSettingsEntity = new NodejsSettingsEntity(); goto b4196; Ee88b: $nodejsSettingsEntity->setSite($siteEntity); goto aa344; ed4b8: throw new \Exception(implode("\73\x20", $errorMessages)); goto E57f4; faf6c: $siteEntity->setCertificate($certificateEntity); goto c808c; f560b: A35fe: goto d19e3; a1e0a: $rsaKeyGenerator = new RsaKeyGenerator(); goto A5270; a39b3: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto D6f74; Ce27c: } private function createPythonSite(string $domainName, string $pythonVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto beddd; c18f7: $certificateEntity->setDefaultCertificate(true); goto c9748; f2c12: C9e66: goto A3c69; Ab1af: $siteConstraints = $this->validator->validate($siteEntity); goto Dc52b; F4ea8: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto B4e9e; faacc: $pythonSite->setCertificate($certificateEntity); goto aaf4f; F2a5f: $pythonSite->setSubdomain($subdomain); goto C051f; e65a5: $csr = $csrGenerator->generate(); goto Aaa7a; Acd4e: $pythonSiteCreator->createPrivateKeyAndCertificate(); goto D680f; c4609: $siteEntity->setUserPassword($siteUserPassword); goto De5ad; D7808: $rsaKeyGenerator = new RsaKeyGenerator(); goto D8c2e; Dc52b: $pythonSettingsConstraints = $this->validator->validate($pythonSettingsEntity); goto Fe3bd; C3b22: $pythonSite->setUser($siteEntity->getUser()); goto Bf9a7; d7729: $pythonSettingsEntity->setSite($siteEntity); goto Ab1af; cb563: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\56\57\x2e\x2e\57\56\x2e\x2f\162\145\x73\157\x75\162\x63\145\163\57\x6e\x67\151\x6e\x78\57\166\150\157\x73\164\137\164\x65\x6d\x70\x6c\x61\164\x65\57\x72\x65\x64\151\162\x65\x63\164\55\150\164\x74\x70\63"); goto D9100; afaf2: $constraintViolationList = new ConstraintViolationList(); goto e9e80; f533a: $pythonSiteCreator->reloadNginxService(); goto C6b31; b563a: $pythonSite = new PythonSite(); goto C3b22; a5695: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto c7b17; D8c2e: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto d1f57; beddd: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto F5e80; febaa: $subdomain = $resolvedDomainName->subDomain()->toString(); goto b801c; F2644: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto C248d; a053a: throw new \Exception(implode("\73\40", $errorMessages)); goto f2c12; Bd7cb: $pythonSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto B1c7d; adb5a: $siteEntity = $this->siteEntityManager->createEntity(); goto b0ea1; Edde4: $this->siteEntityManager->updateEntity($siteEntity); goto ab67e; Ef319: $pythonSiteCreator->createRootDirectory(); goto dcd34; D680f: $pythonSiteCreator->createNginxVhost(); goto f533a; B1c7d: $pythonSiteCreator = new PythonSiteCreator($pythonSite); goto A0be0; e507c: return $siteEntity; goto D5f62; D9100: fcf30: goto aad83; E1b1c: $vhostTemplate = sprintf("\45\x73\x25\163", $redirectionVhostTemplate, $vhostTemplate); goto F5d8a; E7150: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto e65a5; c7b17: $vhostTemplate->resetProcessors(); goto F4ea8; dcd34: $pythonSiteCreator->createLogrotateFile(); goto D4ab5; Be3f5: if (!(true === is_null($subdomain) || "\x77\x77\167" == $subdomain)) { goto e52c0; } goto e9712; F5d8a: c9f7c: goto a48e1; ed68d: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto d892f; B9311: $subjectAlternativeNames[] = $registrableDomain; goto c20b2; B1288: if (!(true === is_null($subdomain))) { goto a5f4b; } goto B8c4a; A3c69: $certificateEntity = $this->certificateEntityManager->createEntity(); goto D7fa9; D23b3: $siteEntity->setVhostTemplate($vhostTemplate); goto a53c8; C3d1f: $vhostTemplate = new PythonVhostTemplate($pythonSite); goto a5695; f8bb3: $certificateEntity->setCsr($csr); goto F2644; aad83: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto E410f; B8c4a: $subjectAlternativeNames[] = sprintf("\167\167\x77\56\x25\163", $domainName); goto d57b3; bcdbc: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto E7150; de568: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::PYTHON_VHOST_TEMPLATE_NAME); goto E69c5; fba7e: $constraintViolationList->addAll($pythonSettingsConstraints); goto b4b71; D4ab5: $pythonSiteCreator->writePythonVersionFile(); goto Acd4e; De5ad: $siteEntity->setRootDirectory($domainName); goto Be3f5; ab67e: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto e507c; e9e80: $constraintViolationList->addAll($siteConstraints); goto fba7e; Cf144: $siteEntity->setDomainName($domainName); goto c430d; F5e80: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto febaa; C051f: $pythonSite->setRootDirectory($siteEntity->getRootDirectory()); goto faacc; e07ee: $pythonSite->setRegistrableDomain($registrableDomain); goto F2a5f; E8b94: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Edde4; A0be0: $pythonSiteCreator->createUser(); goto Ef319; d1f57: $subjectAlternativeNames = []; goto B1288; Fe3bd: if (!(count($siteConstraints) || count($pythonSettingsConstraints))) { goto C9e66; } goto afaf2; a53c8: $pythonSettingsEntity = new PythonSettingsEntity(); goto dbce6; Ac8c6: goto fcf30; goto c4142; c20b2: Dd6f9: goto bcdbc; Bf9a7: $pythonSite->setUserPassword($siteEntity->getUserPassword()); goto a81c0; E410f: if (!(false === empty($redirectionVhostTemplate))) { goto c9f7c; } goto E1b1c; e9712: if (true === isset($_ENV["\x41\120\120\137\x48\x54\x54\x50\63"]) && "\164\162\x75\145" === $_ENV["\x41\120\120\137\x48\x54\124\120\63"]) { goto F83a5; } goto e85d8; c9748: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto f8bb3; e85d8: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\57\56\x2e\x2f\56\x2e\x2f\x72\x65\163\x6f\165\x72\x63\145\x73\57\x6e\x67\151\x6e\x78\x2f\166\x68\157\x73\x74\137\164\x65\x6d\160\154\x61\164\145\57\x72\x65\x64\151\162\x65\143\164"); goto Ac8c6; dbce6: $siteEntity->setPythonSettings($pythonSettingsEntity); goto Caa30; E69c5: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto adb5a; c4142: F83a5: goto cb563; b4b71: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto a053a; a48e1: e52c0: goto D23b3; D0cda: if (!(false === is_null($subdomain) && "\x77\x77\167" == $subdomain)) { goto Dd6f9; } goto B9311; e26cf: $siteEntity->setCertificate($certificateEntity); goto b563a; C6b31: $pythonSiteCreator->resetPermissions(); goto C3d1f; Caa30: $pythonSettingsEntity->setPythonVersion($pythonVersion); goto A4a76; Aaa7a: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto c18f7; B4e9e: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto ed68d; A4a76: $pythonSettingsEntity->setPort($port); goto d7729; d57b3: a5f4b: goto D0cda; c430d: $siteEntity->setUser($siteUser); goto c4609; C248d: $certificateEntity->setCertificate($selfSignedCertificate); goto e26cf; aaf4f: $pythonSite->setPythonSettings($pythonSettingsEntity); goto Bd7cb; d892f: $vhostTemplate->build(); goto E8b94; D7fa9: $certificateEntity->setSite($siteEntity); goto D7808; b801c: $subdomain = false === empty($subdomain) ? $subdomain : null; goto de568; b0ea1: $siteEntity->setType(SiteEntity::TYPE_PYTHON); goto Cf144; a81c0: $pythonSite->setDomainName($domainName); goto e07ee; D5f62: } private function createStaticSite(string $domainName, string $siteUser, string $siteUserPassword) : SiteEntity { goto f59c8; Bf797: F2871: goto f3837; F9b97: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto fbfc8; D0da3: $staticSiteCreator->createNginxVhost(); goto Fb061; D55d9: $subdomain = $resolvedDomainName->subDomain()->toString(); goto Efbad; B64f1: $staticSiteCreator = new StaticSiteCreator($staticSite); goto E55d2; F5644: $certificateEntity->setCsr($csr); goto ff9e2; a8b99: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto F8c82; bfa01: $certificateEntity->setDefaultCertificate(true); goto F3b8c; B4a19: goto F2871; goto Eea16; b6b81: $staticSiteCreator->resetPermissions(); goto a04d0; Fb061: $staticSiteCreator->reloadNginxService(); goto b6b81; E55d2: $staticSiteCreator->createUser(); goto E9a91; Eb53e: $certificateEntity->setCertificate($selfSignedCertificate); goto Ef5bc; a04d0: $vhostTemplate = new StaticVhostTemplate($staticSite); goto F9a23; e0e7f: $rsaKeyGenerator = new RsaKeyGenerator(); goto a8b99; F3b8c: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto F5644; A7726: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\56\57\x2e\x2e\x2f\56\x2e\x2f\x72\145\x73\157\165\162\143\145\163\57\x6e\x67\x69\x6e\x78\57\x76\150\x6f\x73\164\137\164\x65\x6d\160\154\x61\164\x65\57\162\x65\x64\x69\x72\x65\143\x74\55\x68\164\164\x70\x33"); goto Bf797; fbfc8: throw new \Exception(implode("\73\x20", $errorMessages)); goto Ee9fa; b061b: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::STATIC_SITE_VHOST_TEMPLATE_NAME); goto A5e42; f03f4: $vhostTemplate = sprintf("\45\x73\45\163", $redirectionVhostTemplate, $vhostTemplate); goto f8d15; Efbad: $subdomain = false === empty($subdomain) ? $subdomain : null; goto b061b; f59c8: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto eabc6; B86c3: $vhostTemplate->resetProcessors(); goto c8417; ccfea: if (!(true === is_null($subdomain) || "\x77\167\167" == $subdomain)) { goto f7c51; } goto b1243; eabc6: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto D55d9; ef7ce: $siteEntity->setType(SiteEntity::TYPE_STATIC); goto b1c53; Adce1: $staticSiteCreator->createIndexHtml(); goto F62be; e10b1: $subjectAlternativeNames[] = sprintf("\167\167\167\56\x25\163", $domainName); goto fbab2; Ef5bc: $siteEntity->setCertificate($certificateEntity); goto d01f4; D0d53: $siteEntity->setUser($siteUser); goto Eeb8e; F9a23: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto B86c3; C5563: $constraintViolationList->addAll($siteConstraints); goto F9b97; Dbd90: $staticSite->setRootDirectory($siteEntity->getRootDirectory()); goto Ee2ae; De3b1: $constraintViolationList = new ConstraintViolationList(); goto C5563; ff9e2: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto Eb53e; E5fbf: if (!(true === is_null($subdomain))) { goto ad510; } goto e10b1; D156a: if (!(false === empty($redirectionVhostTemplate))) { goto d4cfc; } goto f03f4; c8417: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto fce41; A5e42: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto A7a1e; Bd820: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto c4b95; Ee9fa: Ca212: goto ea796; Eeb8e: $siteEntity->setUserPassword($siteUserPassword); goto F7f78; Fd762: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\56\x2f\x2e\x2e\57\56\56\57\162\145\x73\x6f\165\162\x63\x65\x73\57\x6e\147\x69\156\170\x2f\x76\150\x6f\x73\164\137\x74\x65\155\160\154\141\164\145\x2f\x72\145\x64\x69\x72\x65\143\x74"); goto B4a19; ea796: $certificateEntity = $this->certificateEntityManager->createEntity(); goto f6ce3; f6ce3: $certificateEntity->setSite($siteEntity); goto e0e7f; e571a: $staticSite->setUser($siteEntity->getUser()); goto E8f20; F9243: $siteConstraints = $this->validator->validate($siteEntity); goto b97d9; Ee2ae: $staticSite->setCertificate($certificateEntity); goto A03d8; C5251: if (!(false === is_null($subdomain) && "\167\167\x77" == $subdomain)) { goto fa046; } goto E296f; Afbd5: $this->siteEntityManager->updateEntity($siteEntity); goto E1586; F7f78: $siteEntity->setRootDirectory($domainName); goto ccfea; f3837: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto D156a; b7ff3: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto bfa01; F8c82: $subjectAlternativeNames = []; goto E5fbf; A7a1e: $siteEntity = $this->siteEntityManager->createEntity(); goto ef7ce; E1586: return $siteEntity; goto Db2f9; A03d8: $staticSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto B64f1; d01f4: $staticSite = new StaticSite(); goto e571a; A335f: $staticSite->setRegistrableDomain($registrableDomain); goto ed655; Eea16: Ddd4c: goto A7726; Fa768: $csr = $csrGenerator->generate(); goto b7ff3; ea6d1: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto Afbd5; f8d15: d4cfc: goto c3469; fce41: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto b2d3b; b97d9: if (!count($siteConstraints)) { goto Ca212; } goto De3b1; F62be: $staticSiteCreator->createPrivateKeyAndCertificate(); goto D0da3; Ab6e0: $siteEntity->setVhostTemplate($vhostTemplate); goto F9243; e25dd: $staticSiteCreator->createLogrotateFile(); goto Adce1; fbab2: ad510: goto C5251; b2d3b: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto ded82; E8f20: $staticSite->setUserPassword($siteEntity->getUserPassword()); goto B0d8e; b1c53: $siteEntity->setDomainName($domainName); goto D0d53; Be977: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto ea6d1; E9a91: $staticSiteCreator->createRootDirectory(); goto e25dd; F91a1: fa046: goto Bd820; ed655: $staticSite->setSubdomain($subdomain); goto Dbd90; B0d8e: $staticSite->setDomainName($domainName); goto A335f; c4b95: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto Fa768; ded82: $vhostTemplate->build(); goto Be977; E296f: $subjectAlternativeNames[] = $registrableDomain; goto F91a1; c3469: f7c51: goto Ab6e0; b1243: if (true === isset($_ENV["\101\x50\120\137\x48\x54\x54\x50\x33"]) && "\164\162\x75\x65" === $_ENV["\101\x50\x50\x5f\x48\x54\124\x50\x33"]) { goto Ddd4c; } goto Fd762; Db2f9: } private function createReverseProxySite(string $domainName, string $reverseProxyUrl, string $siteUser, string $siteUserPassword) : SiteEntity { goto Ca018; bf4fe: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto cebd2; Aa14f: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto f40af; f3be2: if (!(false === empty($redirectionVhostTemplate))) { goto b54f5; } goto c01ee; B2447: B22b5: goto C86bd; A2adb: $subjectAlternativeNames[] = $registrableDomain; goto Da5fe; Ca018: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto F5440; c2c94: $reversProxySiteCreator->createPrivateKeyAndCertificate(); goto fa0f2; Dd021: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto ebc7d; E0059: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Eb3a2; D3446: $vhostTemplate->resetProcessors(); goto Dc54f; c2f57: $reversProxySiteCreator = new ReverseProxySiteCreator($reverseProxySite); goto Ad0bd; Ae29a: b914a: goto Ce7d2; f466d: $constraintViolationList = new ConstraintViolationList(); goto b067a; Fdd42: $reverseProxySite->setDomainName($domainName); goto E31ad; e26b8: $reversProxySiteCreator->resetPermissions(); goto Ec43c; E31ad: $reverseProxySite->setRegistrableDomain($registrableDomain); goto b8e99; e95af: $siteEntity->setType(SiteEntity::TYPE_REVERSE_PROXY); goto bf0ef; fa3c9: b54f5: goto C3c09; Fa80f: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::REVERSE_PROXY_VHOST_TEMPLATE_NAME); goto bf4fe; a343c: $siteEntity->setUser($siteUser); goto B4053; A95d2: a97d3: goto ec451; Bb607: return $siteEntity; goto F774b; C3e1a: $vhostTemplate->build(); goto B9907; b8e99: $reverseProxySite->setSubdomain($subdomain); goto d51ea; b067a: $constraintViolationList->addAll($siteConstraints); goto E0059; B4053: $siteEntity->setUserPassword($siteUserPassword); goto Aa146; Eb06a: $reverseProxySite->setUser($siteEntity->getUser()); goto D5192; E235b: $csr = $csrGenerator->generate(); goto F0311; Ce7d2: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto f3be2; Dc54f: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto Bf009; b3781: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto D3446; A920b: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto efc0c; Aef5c: $reverseProxySite->setReverseProxyUrl($reverseProxyUrl); goto ac5b6; ac5b6: $reverseProxySite->setVhostTemplate($siteEntity->getVhostTemplate()); goto c2f57; Fe085: $reversProxySiteCreator->reloadNginxService(); goto e26b8; C6ee2: $siteEntity->setCertificate($certificateEntity); goto Ae2c2; eade4: $this->siteEntityManager->updateEntity($siteEntity); goto Bb607; C86bd: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\57\x2e\x2e\x2f\56\x2e\57\x72\145\x73\x6f\165\162\x63\x65\163\x2f\x6e\147\x69\x6e\x78\57\x76\150\x6f\x73\x74\137\164\145\155\160\x6c\141\164\145\x2f\162\145\x64\151\162\x65\x63\164\55\x68\164\x74\160\63"); goto Ae29a; ebc7d: $subjectAlternativeNames = []; goto c9d53; Dfdab: $subjectAlternativeNames[] = sprintf("\x77\x77\167\56\x25\x73", $domainName); goto E7e0d; Ec43c: $vhostTemplate = new ReverseProxyVhostTemplate($reverseProxySite); goto b3781; c9d53: if (!(true === is_null($subdomain))) { goto d90f4; } goto Dfdab; Cd459: if (!(false === is_null($subdomain) && "\167\x77\167" == $subdomain)) { goto Aa2fa; } goto A2adb; C3c09: d3364: goto e5246; D02fa: $reversProxySiteCreator->createLogrotateFile(); goto c2c94; b9e8e: if (!count($siteConstraints)) { goto a97d3; } goto f466d; Aa146: $siteEntity->setRootDirectory($domainName); goto Fed46; bf0ef: $siteEntity->setDomainName($domainName); goto a343c; Eec37: if (!(true === is_null($subdomain) || "\x77\167\167" == $subdomain)) { goto d3364; } goto fb613; fb613: if (true === isset($_ENV["\101\x50\x50\x5f\x48\124\x54\120\x33"]) && "\164\162\x75\145" === $_ENV["\x41\120\120\137\110\x54\124\x50\63"]) { goto B22b5; } goto b13d3; e5246: $siteEntity->setVhostTemplate($vhostTemplate); goto E9a20; d51ea: $reverseProxySite->setRootDirectory($siteEntity->getRootDirectory()); goto A2a8b; f40af: $certificateEntity->setCertificate($selfSignedCertificate); goto C6ee2; Dac76: $subdomain = false === empty($subdomain) ? $subdomain : null; goto Fa80f; c25cd: $certificateEntity->setDefaultCertificate(true); goto ba869; D5192: $reverseProxySite->setUserPassword($siteEntity->getUserPassword()); goto Fdd42; E7e0d: d90f4: goto Cd459; F5440: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto B2df0; ffb57: $reversProxySiteCreator->createRootDirectory(); goto D02fa; Bf009: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto ad2b2; a2e09: $certificateEntity->setCsr($csr); goto Aa14f; B9907: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto f1859; cebd2: $siteEntity = $this->siteEntityManager->createEntity(); goto e95af; Fed46: $siteEntity->setReverseProxyUrl($reverseProxyUrl); goto Eec37; d13c5: $rsaKeyGenerator = new RsaKeyGenerator(); goto Dd021; efc0c: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto E235b; E9a20: $siteConstraints = $this->validator->validate($siteEntity); goto b9e8e; d23cc: $certificateEntity->setSite($siteEntity); goto d13c5; Ad0bd: $reversProxySiteCreator->createUser(); goto ffb57; b13d3: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\x2e\x2f\x2e\x2e\57\56\x2e\57\x72\x65\x73\x6f\165\162\143\145\x73\x2f\x6e\147\x69\156\x78\57\166\150\x6f\163\164\x5f\164\145\155\x70\154\141\164\x65\x2f\x72\x65\x64\x69\x72\x65\x63\x74"); goto Db258; Da5fe: Aa2fa: goto A920b; A2a8b: $reverseProxySite->setCertificate($certificateEntity); goto Aef5c; F0311: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto c25cd; B2df0: $subdomain = $resolvedDomainName->subDomain()->toString(); goto Dac76; f1859: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto eade4; Db258: goto b914a; goto B2447; ba869: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto a2e09; c01ee: $vhostTemplate = sprintf("\45\x73\45\163", $redirectionVhostTemplate, $vhostTemplate); goto fa3c9; Eb3a2: throw new \Exception(implode("\73\x20", $errorMessages)); goto A95d2; fa0f2: $reversProxySiteCreator->createNginxVhost(); goto Fe085; Ae2c2: $reverseProxySite = new ReverseProxySite(); goto Eb06a; ad2b2: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto C3e1a; ec451: $certificateEntity = $this->certificateEntityManager->createEntity(); goto d23cc; F774b: } public function installedWordPressSite(Request $request) : Response { goto fe770; a6f52: c90b3: goto e3bf3; f31bd: a9d86: goto a8582; fe770: $session = $request->getSession(); goto Eebf6; f0971: if (false === empty($siteCredentials)) { goto a9d86; } goto fce59; fce59: $response = $this->redirect($this->generateUrl("\x63\154\160\137\163\x69\164\x65\163")); goto Cb049; b7d56: return $response; goto a6f52; e3bf3: return $response; goto b7172; Eebf6: $siteCredentials = $session->get("\x73\151\x74\145\x43\x72\x65\x64\x65\x6e\164\151\141\154\x73"); goto f0971; Cb049: goto c90b3; goto f31bd; a8582: $siteCredentials = $this->renderSiteCredentials($siteCredentials); goto C8ce1; C8ce1: $response = $this->render("\106\162\157\x6e\x74\x65\156\144\x2f\123\151\164\x65\x2f\x4e\x65\167\57\x77\x6f\x72\x64\160\162\145\163\x73\x2d\151\156\x73\x74\x61\x6c\154\145\144\x2e\150\164\x6d\x6c\56\164\x77\x69\x67", ["\x73\x69\x74\x65\103\162\x65\x64\145\156\164\x69\x61\154\163" => $siteCredentials]); goto b7d56; b7172: } private function renderSiteCredentials(array $siteCredentials) : string { goto c7b68; D4c74: F89c5: goto D04b0; c7b68: $renderedCredentials = ''; goto cce43; cce43: foreach ($siteCredentials as $section => $sectionData) { goto Dde71; aaa0f: $renderedCredentials .= "\x2d\x2d\x2d\55\55\55\55\x2d\x2d\x2d\x2d\x2d\55\55\55\x2d\55\x2d\x2d\x2d\x2d\55\x2d\x2d\x2d\x2d\x2d\x2d\55\55\55\55\55\x2d\55\x2d\55\x2d\55\x2d\55\x2d\55\55\x2d\x2d\55\55\55\55\55\x2d\55\x2d" . PHP_EOL; goto A8401; d6844: fbb0d: goto D1999; A7d57: e8bd3: goto C30a2; Dde71: $renderedCredentials .= $section . PHP_EOL; goto aaa0f; A8401: foreach ($sectionData as $key => $value) { $renderedCredentials .= sprintf("\45\x73\72\x20\x25\x73", $key, $value) . PHP_EOL; Be288: } goto A7d57; C30a2: $renderedCredentials .= PHP_EOL; goto d6844; D1999: } goto D4c74; D04b0: return $renderedCredentials; goto Fdf36; Fdf36: } private function getVhostTemplateEntity(string $name) : mixed { goto Ccf5e; b73fb: if (!(true === is_null($vhostTemplateEntity))) { goto A53cf; } goto Bd010; Bd010: throw new \Exception($this->translator->trans("\126\x68\157\x73\x74\40\124\x65\155\160\x6c\141\164\x65\x20\45\166\x68\x6f\163\x74\x54\145\155\160\154\141\164\145\x25\x20\x64\157\145\163\x20\156\x6f\x74\40\145\170\151\163\x74\56", ["\x25\x76\150\x6f\x73\164\x54\x65\155\x70\x6c\141\164\145\45" => $name])); goto eba06; Ccf5e: $vhostTemplateEntity = $this->vhostTemplateEntityManager->findOneByName($name); goto b73fb; eba06: A53cf: goto E9359; E9359: return $vhostTemplateEntity; goto Cc30c; Cc30c: } private function getConstraintViolationListErrorMessages(ConstraintViolationList $constraintViolationList) : array { goto c4593; A5f45: foreach ($constraintViolationList as $constraint) { $errorMessages[] = sprintf("\45\x73\x3a\x20\x25\163", $constraint->getPropertyPath(), $constraint->getMessage()); eb67f: } goto A9892; A9892: A69e1: goto B41ca; c4593: $errorMessages = []; goto A5f45; B41ca: return $errorMessages; goto D7162; D7162: } private function generateNameFromDomainName(string $domainName) : string { goto Ef4c8; Ef4c8: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Dc8da; B268c: goto A12ba; goto e4181; d9c87: $explodedRegistrableDomain = explode("\56", $registrableDomain); goto A234e; b48d6: $subdomain = $resolvedDomainName->subDomain()->toString(); goto d9c87; A234e: if ("\x77\167\167" == $subdomain) { goto Ed2de; } goto Bcfe2; Bcfe2: $name = $explodedRegistrableDomain[0] ?? ''; goto B16c5; B8d32: $name = sprintf("\x25\163\55\x25\x73", $explodedRegistrableDomain[0] ?? '', implode("\x2d", $explodedSubdomain)); goto e7765; e4181: Ed2de: goto deec0; e7765: E09d0: goto B268c; cab4d: $explodedSubdomain = explode("\56", $subdomain); goto B8d32; Dc8da: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto b48d6; D0660: A12ba: goto B8643; B16c5: if (!(false === empty($subdomain))) { goto E09d0; } goto cab4d; B8643: return $name; goto C3e3f; deec0: $name = $explodedRegistrableDomain[0] ?? ''; goto D0660; C3e3f: } private function getUniqueDatabaseName(string $databaseName) : string { goto d3bf7; a893c: e08f7: goto Eb53f; Bdb23: return $uniqueDatabaseName; goto fbee7; c6fc1: $databaseExists = in_array($uniqueDatabaseName, $databases); goto ee84e; ee84e: $i++; goto C3c0f; e74ba: $databaseConnection = new DatabaseConnection($activeDatabaseServerEntity); goto E2d24; E2d24: $databases = $databaseConnection->getDatabases(); goto a893c; d7020: F537f: goto Bdb23; d3bf7: $uniqueDatabaseName = $databaseName; goto Fd337; E9f59: bf430: goto c6fc1; d7668: $uniqueDatabaseName = sprintf("\x25\163\x2d\x64\x62", $uniqueDatabaseName); goto Ce95b; Eb53f: if (!(0 < $i)) { goto bf430; } goto Bf9b3; bd119: $i = 0; goto Dbf2f; C3c0f: if (true === $databaseExists) { goto e08f7; } goto d7020; Dbf2f: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto e74ba; Bf9b3: $uniqueDatabaseName = sprintf("\45\x73\55\45\163", $databaseName, $i); goto E9f59; Ce95b: d1191: goto bd119; Fd337: if (!(strlen($uniqueDatabaseName) <= 3)) { goto d1191; } goto d7668; fbee7: } private function getUniqueDatabaseUserName(string $databaseUserName) : string { goto b6ee9; a8338: $databaseUserEntity = $this->databaseUserEntityManager->findOneByUserName($uniqueDatabaseUserName); goto Aebcb; F192a: $uniqueDatabaseUserName = mb_substr($uniqueDatabaseUserName, 0, 32); goto Aa081; Aba51: $i = 0; goto Ff5d4; b41e3: $uniqueDatabaseUserName = sprintf("\45\x73\55\45\x73", $databaseUserName, $i); goto B75eb; c8cd9: if (false === is_null($databaseUserEntity)) { goto b03ce; } goto D6590; b6ee9: $uniqueDatabaseUserName = $databaseUserName; goto d052e; B75eb: e92c0: goto a8338; A68ba: cb1e0: goto Aba51; Ff5d4: b03ce: goto cb6a0; D6590: F636a: goto F192a; Aebcb: $i++; goto c8cd9; e05f0: $uniqueDatabaseUserName = sprintf("\45\x73\x2d\144\x62", $uniqueDatabaseUserName); goto A68ba; cb6a0: if (!(0 < $i)) { goto e92c0; } goto b41e3; Aa081: return $uniqueDatabaseUserName; goto Cbd63; d052e: if (!(strlen($uniqueDatabaseUserName) <= 3)) { goto cb1e0; } goto e05f0; Cbd63: } private function hasPermissions() : bool { goto c3cfd; a3463: if (!(UserEntity::ROLE_USER != $user->getRole())) { goto f626c; } goto ca28f; ca28f: return true; goto Bc633; c3cfd: $user = $this->getUser(); goto a3463; Bc633: f626c: goto c3b9c; c3b9c: return false; goto B5c78; B5c78: } }
